#!/bin/bash  
#
#####################################################################
#
# Program Name: get_buoy.sh
#
# Purpose: Get buoy data for matchups vs goessst
#    -- Since the buoy data file is created by ncep at HH:50, get 
#   the previous hour's file if running earlier in the hour
#
# Usage: get_buoy.sh
#
# Change history:
#     ??????
#     09/03/04   M. Fan  (PSGS)
#                1) Add comment blocks
#                2) use set_app_env.sh 
#                -- modified from get_buoy_dist5.sh
#
#####################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#         daily log file
#----------------------------------------------------------------

while getopts l: optionName
do
            case $optionName in
            l)   datestring=`date -u +%j`
            ##   filename="$OPTARG"
                 logname=$scriptname
                 exec >> $LOGDIR/$logname.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done


# set remote server
#--------------------------
remoteServer=10.144.3.42     # satepsdist5  ## rip 28may2010 - files arriving late at dist5
remoteUser=oper
remoteRootDir=/data/dds

# Create directory and filename for most recent buoy data file
#   Since the buoy data file is created by ncep at HH:50, get 
#   the previous hour's file if running earlier in the hour.
#   NCEP file: /com/nesdis/para/nesdis.YYYYMMDD/buoysst.ascii_HH
#-----------------------------------------------------------------------
cymd=$( date -u  -d'50 minutes ago'   +%Y%m%d )
cyj=$(  date -u  -d'50 minutes ago'   +%Y%j )
hour=$( date -u  -d'50 minutes ago'   +%H )

# --- remote directory
    remoteDir=${remoteRootDir}

# --- remote file name
    remoteName=buoysst.ascii_${hour}.${cymd}
    remoteFile=${remoteDir}/$remoteName

# --- local file names
    localNameShort=Buoysst.${hour}
    localNameLong=Buoysst.${hour}.${cyj}
    localDir=$HOME/mcidas/data


echo  "=============================================================="
echo " Start $scriptname at $(date) "

echo "          cymd = $cymd "
echo "           cyj = $cyj "
echo "          hour = $hour "
echo "     remoteDir = $remoteDir "
echo "    remoteFile = $remoteFile "
echo "     localName = $localNameLong "
echo "      localDir = $localDir "

# go to mcidas data directory
#------------------------------
cd $localDir
echo "Return code from cd localDir was $?"

# Check if already have file

if [[ -s $localNameLong ]]  &&  [[ -s $localNameShort ]]  
then
   cmp  $localNameShort   $localNameLong 
   if  [  $? -eq 0 ] ; then
      echo "  Buoy data already up-to-date $localNameLong"
      exit 0
   fi 
fi 

# clean old file
#------------------
rm -f $localNameShort 

# fetch the data
#------------------------------------------
scptime   -20  $remoteUser@$remoteServer:$remoteFile   $localDir/$localNameLong
rc_scp=$?
if [ -s $localNameLong ]  ; then
   echo "Buoy data fetching successfuly" 
   cp  -p $localNameLong  $localNameShort
else 
   echo "Buoy data fetching failed at $(date -u) "
fi

# cleanup
#------------------------------
find .  -type f -mmin +4320 | grep Buoysst |xargs -i rm {}

echo "End $scriptname at `date -u`\n"
echo ===============================================================
