#!/bin/bash
#
#########################################################################################
#
# Program Name: buoyMatch_goes.sh
#
# Purpose: generate buoy matchup, the distribute to server
#          -- buoy data comes at HH:50
#
# Usage: buoyMatch_goes.sh  [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that script start to run.
#
#
# Prerequisite: The corresponding Bayesian SST processing has beed finished
#               Current hour AREA files: 131, 0142, 1142, 2142 , 
#                            GRID files: 1420, 1421, and 
#                            buoy obs:   buoysst.hh 
#               are avaiable if take GOES_NE as an example 
#
#
# Scripts called:
#           1. set_app_env.sh
#           2. sendBuoyMatch_goes.sh
#           3. set_server_Ops.sh, set_server_Test.sh, or set_server_Backup.sh by sendBuoyMatch_goes.sh
#
# Program called:  buoy_cpo_goes.k
#
# Change History:
#   09/04/06   M. Fan (PSGS) --  Modified from buoyMatch_msg.sh (2009 version)
#
#######################################################################################

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

buoy_program=buoy_cpo_goes.k

table=$SCRIPTDIR/PROC.TABLE
RegName=GOES
RegInfo=$( grep -ve ^# $table | grep -e $RegName )
isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
isBackup=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $3}' )


# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#---------------------------------------------------------------
 while getopts l: optionName
 do
             case $optionName in
             l)   logname="$OPTARG"
                  datestring=`date -u +%Y%m%d.%j.%H%M`
                  logname="$logname.$datestring.log"
                  export   LOGFILE=$LOGDIR/$logname
                  exec >> $LOGFILE   2>&1 ;;
             ?)   echo "Usage: $scriptname  -l logfile_name \n";;
            esac
 done

#
echo "Begin $scriptname $* at $(date)"
echo "============================================="


## goto the directory where buoy match program will run 
#------------------------------------------------------
cd $BUOYDIR


## Get time reference 
#-----------------------------------
now_hh=$(date -u +%H)
now_mm=$(date -u +%M)
send_date=$(  date -u +%Y%j )
send_year=$(  date -u +%Y )
send_day=$(  date -u +%j )
send_hour=$(  date -u +%H )

## Check whether buoy obs are available yet (arrive about HH:50)
#  If not ready, then wait. Otherwise put buoy data to file $buoydata
#---------------------------------------------------------------------
    if  [ $now_mm -lt  53 ]
    then
       echo " Buoy data not yet ready - now is $now_hh:$now_mm - waiting until $now_hh:52 "
       let sleepminutes=52-$now_mm
       let sleepseconds=60*$sleepminutes
       doecho sleep $sleepseconds
    fi 


# buoy match file name -- for whole GOES:
# -- match string
match_string_for_goes="match_goes_"

# -- Creat datestring for buoy match name
name_datestring="${send_year}_${send_day}.${send_hour}"

# -- File names: buoy match results for GOES
nameB_goes=${match_string_for_goes}${name_datestring}'B'
nameS_goes=${match_string_for_goes}${name_datestring}'S'


# generate buoy match for each sector
#--------------------------------------
 exist_img=0
 h1=$( expr 23 + $now_hh )
 now_h1=$( expr $h1 % 24 )

goesName=" gwn gws gen  ges "
for RegName in $goesName
do
     echo "-----------------------------------"
     echo "-----------------------------------"
     echo "${RegName}" | grep gen    &&   num=1
     echo "${RegName}" | grep gwn    &&   num=2
     echo "${RegName}" | grep ges    &&   num=3
     echo "${RegName}" | grep gws    &&   num=4

     match_string="match_${RegName}_"
     out_area=${num}42
     grid_0=${out_area}0

    imglist.k LD/A.$out_area 
    string182="$( imglist.k LD/A.${out_area} |grep ${out_area} |head -1 )"
    out_hh="$( echo $string182 | awk '{print $7}'|cut -c1-2)"

    if [ $num -ne 2 ] && [ $now_h1 -ne $out_hh ]; then
        echo "no expected image for ${RegName}"
        echo " "
        echo "-----------------------------------"
    elif [ $num -eq 2 ] && [ $now_hh -ne $out_hh ]; then
        echo "no expected image for ${RegName}"
        echo " "
        echo "-----------------------------------"
    else
          exist_img=$( expr 1 + $exist_img )
#    --- buoy SST
         ls -la $MCDATDIR/buoysst.$now_hh
         echo "cat  $MCDATDIR/buoysst.$now_hh  > buoydata.${RegName}"
         cat  $MCDATDIR/buoysst.$now_hh  > buoydata.${RegName}

##   --- perform buoy matchup
         DATESTRING="   DATE=$send_date HOUR=$send_hour"    
         echo " $buoy_program    $DATESTRING GRID=${grid_0} REGION=${RegName}"
                $buoy_program    $DATESTRING GRID=${grid_0} REGION=${RegName}

#   ---File names: buoy match results
         nameB=${match_string}${name_datestring}'B'
         nameS=${match_string}${name_datestring}'S'
         ls -l $BUOYDIR/$nameB
         ls -l ${BUOYDIR}/$nameS
         echo "$BUOYDIR/$nameB >> $BUOYDIR/$nameB_goes"
         cat $BUOYDIR/$nameB >> $BUOYDIR/$nameB_goes
         cat $BUOYDIR/$nameS >> $BUOYDIR/$nameS_goes
         rm $BUOYDIR/$nameB   $BUOYDIR/$nameS
    fi
done

## Check if image is the expected one
#  If not, exit
#------------------------------------
if [ $exist_img -eq 0 ]; then
      echo "Expected Image Does Not Exist -- Exit the Program"
      exit
else
     ls -l $BUOYDIR/$nameB_goes
     ls -l $BUOYDIR/$nameS_goes
  
     if [ -s $BUOYDIR/$nameB_goes ]; then
         echo "buoy matchup generate SUCCESS"
#        --- send buoy matchups to product server
         send_date_string=${send_year}_${send_day}_${send_hour}
         echo "isOps = $isOps"       |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_goes.sh  $send_date_string  isOps
         echo "isTest = $isTest"     |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_goes.sh  $send_date_string  isTest
         echo "isBackup = $isBackup" |grep TRUE   && doecho  $SCRIPTDIR/sendBuoyMatch_goes.sh  $send_date_string  isBackup
     else
         echo "buoy matchup generate FAIL"
     fi
fi

echo " End $scriptname at $(date) "

