#!/bin/ksh   
#
########################################################
# Name:     check_gsst.sh
# Usage:    check_gsst.sh
# Language: Korn-shell script
# To Run on gp3 (sgi-???)
# Purpose:  Report status of goes-sst processing
# Method:   checks presence of hourly and 3-hourly composite sst outpout files
# Author:   R.Potash/PRC  November 2000
# Updates:  Convert to bash (3/02)
#
# 06/02/09:  M. Fan  (PSGS) 
#            modified to use set_app_env.sh
#            SST hourly & 3-hourly, buoy match, L2P products are checked
#
#============================================================

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )
curDir=`pwd`


# log file
#-------------
datestring=`date -u +%j`
logname=$(echo $scriptname | sed s/\.sh$// )
logname="$logname.$datestring.log"
LOGFILE=$LOGDIR/$logname
exec >> $LOGFILE   2>&1

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo "`date -u` start $scriptname"              # time stamp


buoydir=$oldBUOYDIR
sstdir=$SSTDIR
L2P_dir=$L2P_SENTDIR
frontalDir=$FRONTDIR/daily_fronts

curdir=`pwd`

name="  goes mtsat msg "

icount=0
for satellite in $name 
do 

# 1. make product names:
#===========================

# set time string 
#-----------------------
    if [[ ` echo $satellite |grep "goes"`  ]]; then
          SAT="GOES"
          epoch_1h=$(  date -u -d' 105 minutes ago '  +"%Y_%j_%H" )

          yrdy_3h=$(   date -u -d' 170 minutes ago '  +"%Y_%j_" )
          hour_3h=$(   date -u -d' 170 minutes ago '  +"%H" )
          hour_3h=$(  printf %2.2d $( expr  $hour_3h - $hour_3h % 3 ) ) 
          epoch_3h=$yrdy_3h$hour_3h

          epoch_buoy=$(  date -u -d' 60 minutes ago '  +"%Y_%j.%H" )
          epoch_frontal=$(   date -u -d' 1440 minutes ago '  +"%Y_%j" )

          l2p_min=45
     fi
     if [[ `echo $satellite | grep "mtsat"` ]]; then
          SAT="MTSAT"
          epoch_1h=$( date -u -d' 95 minutes ago '  +"%Y_%j_%H" )

          yrdy_3h=$(  date -u -d' 140 minutes ago '  +"%Y_%j_" )
          hour_3h=$(  date -u -d' 140 minutes ago '  +"%H" )
          hour_3h=$(  printf %2.2d $( expr  $hour_3h - $hour_3h % 3 )  )
          epoch_3h=$yrdy_3h$hour_3h

          epoch_buoy=$(   date -u -d' 60 minutes ago '  +"%Y_%j.%H" )

          l2p_min=75
     fi
     if [[ `echo $satellite | grep "msg"` ]]; then
          SAT="MSG"
          epoch_1h=$(   date -u -d' 95 minutes ago '  +"%Y_%j_%H" )

          yrdy_3h=$(    date -u -d' 160 minutes ago '  +"%Y_%j_" )
          hour_3h=$(    date -u -d' 160 minutes ago '  +"%H" )
          hour_3h=$(  printf %2.2d $( expr  $hour_3h - $hour_3h % 3 )  )
          epoch_3h=$yrdy_3h$hour_3h

          epoch_buoy=$( date -u -d'60 minutes ago'  "+%Y_%j.%H")
    
          l2p_min=25
     fi

     echo " "
     echo " $SAT products:"
     echo " -------------- "

#  products 
#----------------

     hourly_file="sst1b_${satellite}_${epoch_1h}"

     sst3hour_file="sst3b_${satellite}_${epoch_3h}"
   
     buoy_file="match_${satellite}_${epoch_buoy}"'B.gz'

   ##frontalProductName=gsst_${epoch_frontal}_frt.gz
     frontalProductName=gsst_${epoch_frontal}_frt.png
     frontalProductFile=${frontalDir}/$frontalProductName


# 2. Check whether the expected files are present
#=============================================

     all_ok=0
     hourly_ok=0


     cd  $sstdir
     echo " SST data directory is $sstdir"

# SST hourly
#-----------
     if [[   -s $hourly_file ]]
     then
     echo " OK - File Found  - $SAT Hourly SST - $hourly_file "
     else
        all_ok=-1
        hourly_ok=-1
        echo "ERROR - FILE NOT FOUND !!! - $SAT Hourly SST "
        actual_hourly=`ls -1  sst1b_${satellite}_20??\_???\_[012]?  | tail -1` 
        echo "       Most recent sst composite - expected: $hourly_file"
        echo "       Most recent sst composite - actual:   $actual_hourly"
        echo "                        ......"
        echo " >>>>> If more than two hours behind - Inform Programmer <<<<<"
     fi
     echo " "

# SST 3-hourly
#-------------
     if [[   -s $sst3hour_file ]]
     then
        echo " OK - File Found  - $SAT 3-Hourly SST - $sst3hour_file"
     else
        all_ok=-1
        echo "ERROR - FILE NOT FOUND !!! - $SAT 3-Hourly SST "
        actual_3hour=`ls -1  sst3b_${satellite}_20??\_???\_??  | tail -1` 
        echo "       Most recent 3-hour sst composite - expected: $sst3hour_file"
        echo "       Most recent 3-hour sst composite - actual:   $actual_3hour "
        echo "                        ......"
        echo " >>>>> If more than four hours behind - Inform Programmer <<<<<"
     fi
     echo 

# buoy match
#-----------
     cd $buoydir
     echo " Buoy Match data directory is $buoydir"
     if [[   -s $buoydir/$buoy_file ]]
     then
        echo " OK - File Found  - $SAT Buoy Matchup - $buoy_file"
     else
        all_ok=-1
        echo "ERROR - FILE NOT FOUND !!! - $SAT   Buoy Matchup"
        cd $buoydir 
        actual_buoymatch=`ls -1 match_${satellite}_20??\_???\.[012][0-9]B.gz  | tail -1` 
        echo "       Most recent buoy matchup output expected: $buoy_file"
        echo "       Most recent buoy matchup output actual:   $actual_buoymatch"
        echo "                        ......"
        echo " >>>>>>If more than four hours behind - Inform Programmer<<<<<<"
     fi


# Check for L2P files if hourly check passed
#------------------------------------------
     if [ $hourly_ok -eq 0 ] 
     then
        cd $L2P_dir
        echo " "
        echo " L2P data directory is $L2P_dir"
        find   .  -type f  |grep $SAT >/dev/null
        if [ $? -ne 0 ]
        then
            all_ok=-1
            echo "  $SAT-SST L2P/netcdf: "
            echo "ERROR - Problem with netcdf: No files found - not even old ones"
            echo "          Contact goes-sst programmer "
        else
            find   .  -type f -amin -$l2p_min |grep $SAT >/dev/null
            if [ $? -eq 0 ]
            then
                most_recent=$(ls -tr 2*gz|grep $SAT|tail -1)
                echo " OK - File Found   - $SAT netcdf file - $most_recent"
            else
                all_ok=-1
                most_recent=$(ls -tr 2*gz|grep $SAT|tail -1)
                if [ -f $most_recent ]
                then
                    echo " $SAT NetCDF/L2P Conversion Problem ? "
                    echo "ERROR -  Most Recent product is older than expected "
                    echo "     $(ls -l $most_recent)"
                    echo "                             ......"
                    echo ">>>>>If most recent file is more than 3 hours old, contact programmer<<<<<"
                fi
            fi
        fi
     fi

# New check - daily frontal product
#-----------------------------------
    if [[ ` echo $satellite |grep "goes"`  ]]; then
         echo " "
         echo " front_sst data directory is $frontalDir" 
         hour0=$( date +%H  -d' now       ' )
         if [ $hour0 -gt 11 ]
         then
            if [ -s $frontalProductFile ]
            then
                 echo " OK - File Found   - $SAT Frontal Product  - $frontalProductName"
            else
                  all_ok=-1
                  echo "ERROR - FILE NOT FOUND !!!   -  $SAT Frontal Product Problem"
                  echo "     Expected product: $frontalProductFile  "
                  echo "     Most recent actual product: $( ls -tr $frontalDir |tail -1 )"
            fi
         else
            echo " $SAT Frontal Product: Too early to check"
         fi
     fi

       [ $all_ok -ne 0 ]   &&   icount=$( expr  1 +  $icount )
done



#============================================================

cd $curdir
#
echo
echo " -----------------------------------------------------------"
if [ $icount -eq 0 ] 
then
    echo " SST Products pass all checks. "
    echo " "
    exit 0
else
    echo " "
    echo " PROBLEMS - FILE[s] MISSING in SST Products!!!"
    echo "  "
    echo "         Call Programmer If Message Indicates "
    echo " "
    mail -s"PROBLEMS - FILE[s] MISSING in SST Products!!!-- `uname -n` " bob.potash@noaa.gov < $LOGFILE
    exit 1
fi


#============================================================
