#! /bin/sh
#
#######################################################################################
#
# Program Name: ftpdds-fronts.sh
#
#######################################################################################
#


## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
 export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh

 export scriptname=$( basename $0 )
 export curDir=`pwd`
 export  ERR="!! $scriptname ERROR:"

# log file for sending
#---------------------------------------------------------------------
 export  datestring=`date -u +%Y%j`
 export  logname=sendlog.$(whoami).$(hostname -s).$datestring
 export  SENDLOG=$LOGDIR/$logname
 export  TEMPLOG=$LOGDIR/sendlogTemp.$$
#export  XFERDIR=/data/$(whoami)/xferData      # done in set_app_env
#exec >> $SENDLOG   2>&1


## message
 echo " "
 echo "================================================================"
 echo "`date -u` start $scriptname"              # time stamp

## Usage prompt
#----------------------------
 if [ $# -lt 1 ]
 then
    echo "USAGE:   $scriptname  FileToSend"
    exit -1
 fi

 FileToSend=$1

# Define and verify local directories and file-to-send
#-------------------------------------------------

 remoteServer=10.144.3.7       # DDS
 remoteUser="F0243"            # geo_sst account on DDS
 remoteDir=push

 localDir=$(  dirname  $FileToSend)
 localName=$( basename $FileToSend)

 [ ! -f  $localDir/$localName ] &&  echo "$ERR - File $FileToSend Not Found" && exit 1
 [   -d $XFERDIR ]              ||  mkdir  $XFERDIR
 [ ! -d $XFERDIR ]              &&   echo "$ERR - xferdir $XFERDIR Not Found" && exit 1

# For frontal, need file gzipped  unless png.   
# Assume this is already handled.
 
   remoteName=$localName
   [ -h $XFERDIR/$remoteName ]  || ln -s    $localDir/$localName   $XFERDIR/$remoteName
   rc=$?

 [ $rc -ne 0 ]  &&  echo "$ERR $rc putting $remoteName in $XFERDIR"  &&  exit 1
        echo "DEBUG3"


# Put file on remote server
#    first as <name>.xfer, then rename to strip .xfer
#-------------------------------------------------
 xfer_script=./xferScript.$$

        echo "DEBUG4    xfer_script=$xfer_script"

 temp_remoteName="xfr_${remoteName}"

 cat  <<ENDCAT  >$xfer_script
   ftptime  -200   -v   $remoteServer  <<ENDFTP    >  $TEMPLOG  2>&1
   cd  $remoteDir
      put $XFERDIR/${remoteName}  ${temp_remoteName}
      rename  $temp_remoteName   ${remoteName}
      dir ${remoteName}
   ENDFTP
ENDCAT

 echo " ------------------------ begin ftp script -----------------------------"
   cat $xfer_script
 echo " ------------------------   end ftp script -----------------------------"

 echo " ------------------------ begin execute  script -----------------------------"
 sh $xfer_script
 rc1=$?
 echo " ------------------------   end execute  script -----------------------------"

mv $xfer_script $LOGDIR

 grep 'Transfer complete'  $TEMPLOG  >/dev/null  2>&1   ;  rc2=$?
 grep 'Rename successful'  $TEMPLOG  >/dev/null  2>&1   ;  rc3=$?
 if [ $rc1 -ne 0 ] 
 then
     echo " $ERR sending $localName - ftptime timed out "
 elif [ $rc2 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect SUCCESS message "
 elif [ $rc3 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect rename .xfer message "
 else
    echo Success  $localName sent to DDS at $(date)  |tee   -a   $TEMPLOG
 fi

let rcsum=$rc1+$rc2+$rc3

 if [ $rc  -eq  0 ]
 then
    echo Success  $localName sent to DDS at $(date)  |tee  -a   $TEMPLOG
 else
    echo Failure  $localName  not sent to DDS at $(date)  |tee  -a   $TEMPLOG
 fi

 rm $XFERDIR/$remoteName

[ -f $TEMPLOG ]  &&  cat $TEMPLOG >> $SENDLOG  && rm $TEMPLOG

 echo "End $scriptname  $* at $(date)"
 echo "================================="
 exit $rcsum

