#!/bin/bash

#
### Fetch and prepare ncep data from espc model data server
#   Files are used for generating L2P/netCDF formatted output for GOES-SST
#   This version gets grib2 formatted files, and performs preprocessing
#
#   Replaces  decodes them gets  ** grib2 ** formatted ncep files
#   Original script was get_gfsgrib
#   With GFS upgrades this was replaced by get_gfsgrib2 and preprocess_gfsgrib2.sh 


##---------------------------------------------------------------------
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs

LOGDIR=$HOME/mcidas/logs
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $0  -l logfile_name \n";;
           esac
done
##---------------------------------------------------------------------

echo "===================================================="
echo
echo " Execute $0 at $(date -u)"
echo

export DEBUG=1
echo "DEBUG=$DEBUG"

##------------
# Remote data login name, server, base directory
#     directory name sample :   /com/gfs/prod/gfs.20060322
#     file name samples: gfs.t12z.pgrbf09  gfs.t00z.sfluxgrbf09
                               echo "debug1"
user=oper
ncepDataServer=10.144.3.42
ncepRootDir=/data/ncep/input/gfs/prod

                               echo "debug1"
##------------
# Local directory names 

GRIB2_DIR=/data/$(whoami)/L2P/ncep
GRIB2_DIR_TEMP=$GRIB2_DIR/temp
WORK_DIR=/data/$(whoami)/L2P/work/
WORK_DIR_TEMP=$WORK_DIR/temp


[ ! -d $GRIB2_DIR      ]  && echo "ERROR $0 - missing GRIB2_DIR       = $GRIB2_DIR      " && exit 1
[ ! -d $GRIB2_DIR_TEMP ]  && echo "ERROR $0 - missing GRIB2_DIR_TEMP  = $GRIB2_DIR_TEMP " && exit 2
[ ! -d $WORK_DIR       ]  && echo "ERROR $0 - missing WORK_DIR        = $WORK_DIR       " && exit 3
[ ! -d $WORK_DIR_TEMP  ]  && echo "ERROR $0 - missing WORK_DIR_TEMP   = $WO RK_DIR_TEMP " && exit 4

CONVERT_GRIB=$HOME/mcidas/bin/convert_grib_files.x
                               echo "debug1"
##------------
# Decide which forecast run to get and process

ctoday=$(  date  +%Y%m%d )
cyesterday=$(  date -d ' 1 day ago ' +%Y%m%d )

echo "ctoday=$ctoday"
echo "cyesterday=$cyesterday"

runDate=$ctoday

hh_now=$( date -u +%H )       # text string  between 00 and 23
if   [ $hh_now -lt 03 ] ; then
   HHrun='18'
   runDate=$cyesterday
elif [ $hh_now -lt 09 ] ; then
   HHrun='00'
elif [ $hh_now -lt 15 ] ; then
   HHrun='06'
elif [ $hh_now -lt 21 ] ; then
   HHrun='12'
else 
   HHrun='18'
fi
echo " Time is $(date) ; HHrun is $HHrun"    # Current date/time, model run time

##------------
#  Determine remote directory name and names of files to fetch
 
echo "runDate=$runDate"               # date of model run
remoteNcepDir=$ncepRootDir/gfs.$runDate     # remote server GFS data dir
echo " remoteNcepDir is $remoteNcepDir"

# file name samples: gfs.t12z.pgrb2f09.1p0deg     gfs.t12z.sfluxgrbf09.grib2

Fsuffix='1p0deg'
fname00="gfs.t${HHrun}z.pgrb2f00"
fname03="gfs.t${HHrun}z.pgrb2f03"
fname06="gfs.t${HHrun}z.pgrb2f06"
fname09="gfs.t${HHrun}z.pgrb2f09"
fname12="gfs.t${HHrun}z.pgrb2f12"
fname15="gfs.t${HHrun}z.pgrb2f15"
fname18="gfs.t${HHrun}z.pgrb2f18"

newname00="gfs.t${HHrun}z.pgrb2.1p00.f000"
newname03="gfs.t${HHrun}z.pgrb2.1p00.f003"
newname06="gfs.t${HHrun}z.pgrb2.1p00.f006"
newname09="gfs.t${HHrun}z.pgrb2.1p00.f009"
newname12="gfs.t${HHrun}z.pgrb2.1p00.f012"
newname15="gfs.t${HHrun}z.pgrb2.1p00.f015"
newname18="gfs.t${HHrun}z.pgrb2.1p00.f018"
#          gfs.t06z.pgrb2.1p00.f009
#          gfs.t06z.pgrb2f09.1p0deg


#-------------------------------------------------------------------
# Get and preprocess profile data

  cd $GRIB2_DIR_TEMP

##------------
#Pull model profiles to holding area

  echo " Begin get grib2 profiles hh=3 6 9 12 15 18 at $(date)"
  $HOME/mcidas/bin/sftptime -600 $user@$ncepDataServer << EOF     2>&1
    cd   $remoteNcepDir
    get  $newname00    $fname00.$runDate.$Fsuffix
    get  $newname03    $fname03.$runDate.$Fsuffix
    get  $newname06    $fname06.$runDate.$Fsuffix
    get  $newname09    $fname09.$runDate.$Fsuffix
    get  $newname12    $fname12.$runDate.$Fsuffix
    get  $newname15    $fname15.$runDate.$Fsuffix
    get  $newname18    $fname18.$runDate.$Fsuffix
    bye
EOF
  if  [ $? -ne 0 ] ; then
     echo " $0: !!ERROR  $?: sftptime to ncep Failed or Timed Out !!"
     pwd ; ls -l
  fi

##------------
# Decode  each model profile, then move to work area
  echo " Begin decode profiles hh=3 6 9 12 15 18 at $(date)"

   cd   $GRIB2_DIR_TEMP  || (  echo "ERROR $0 no GRIB2_DIR_TEMP" && exit 1 )

   echo " Debug - pwd=`pwd`"
   echo " Debug - files available for decoding:  `ls`"

   for  fname in  $fname00 $fname03 $fname06 $fname09 $fname12 $fname15 $fname18
   do
       inname=$fname.$runDate.$Fsuffix
                   echo " Debug - now decode $inname " 
       outname=$fname.$runDate.dat
       infile=$GRIB2_DIR_TEMP/$inname
       tmpfile=$WORK_DIR_TEMP/$outname
       outfile=$WORK_DIR/$outname
       if [ -s $tmpfile ] || [ -s $outfile ] ; then 
          echo " Skip preprocessing $inname - already done "
       elif [ -s  $infile ] ; then
           echo "Begin preprocessing $inname $(date)"
           echo "$CONVERT_GRIB  $inname   $WORK_DIR_TEMP"
           time  $CONVERT_GRIB  $inname   $WORK_DIR_TEMP 
           rc=$?
           if [ $rc -eq 0 ]  &&  [ -s  $tmpfile ] ; then
              echo " Successfully preprocessed $inname $(date)"
              mv $tmpfile  $outfile
              mv $infile   $GRIB2_DIR/
           else
              echo " Failed preprocessing $inname - rc-$rc  $(date)"
              ls -l $tmpfile
           fi
       else  
            echo " Input file $inname  not found"
       fi
   done

#-------------------------------------------------------------------


#  Extra protection from disk fill up.
  DIRS="  $GRIB2_DIR  $GRIB2_DIR_TEMP  $WORK_DIR  $WORK_DIR_TEMP  "

 find $GRIB2_DIR       -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $GRIB2_DIR_TEMP  -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $WORK_DIR        -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $WORK_DIR_TEMP   -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}

echo " End  $0 at $(date -u)"
echo ====================================================================
echo " End  $0 at $(date -u)"
echo ====================================================================
#!/bin/bash

#
### Fetch and prepare ncep data from espc model data server
#   Files are used for generating L2P/netCDF formatted output for GOES-SST
#   This version gets grib2 formatted files, and performs preprocessing
#
#   Replaces  decodes them gets  ** grib2 ** formatted ncep files
#   Original script was get_gfsgrib
#   With GFS upgrades this was replaced by get_gfsgrib2 and preprocess_gfsgrib2.sh 


##---------------------------------------------------------------------
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs

LOGDIR=$HOME/mcidas/logs
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $0  -l logfile_name \n";;
           esac
done
##---------------------------------------------------------------------

echo "===================================================="
echo
echo " Execute $0 at $(date -u)"
echo

export DEBUG=1
echo "DEBUG=$DEBUG"

##------------
# Remote data login name, server, base directory
#     directory name sample :   /com/gfs/prod/gfs.20060322
#     file name samples: gfs.t12z.pgrbf09  gfs.t00z.sfluxgrbf09
                               echo "debug1"
user=oper
ncepDataServer=10.144.3.42
ncepRootDir=/data/ncep/input/gfs/prod

                               echo "debug1"
##------------
# Local directory names 

GRIB2_DIR=/data/$(whoami)/L2P/ncep
GRIB2_DIR_TEMP=$GRIB2_DIR/temp
WORK_DIR=/data/$(whoami)/L2P/work/
WORK_DIR_TEMP=$WORK_DIR/temp


[ ! -d $GRIB2_DIR      ]  && echo "ERROR $0 - missing GRIB2_DIR       = $GRIB2_DIR      " && exit 1
[ ! -d $GRIB2_DIR_TEMP ]  && echo "ERROR $0 - missing GRIB2_DIR_TEMP  = $GRIB2_DIR_TEMP " && exit 2
[ ! -d $WORK_DIR       ]  && echo "ERROR $0 - missing WORK_DIR        = $WORK_DIR       " && exit 3
[ ! -d $WORK_DIR_TEMP  ]  && echo "ERROR $0 - missing WORK_DIR_TEMP   = $WO RK_DIR_TEMP " && exit 4

CONVERT_GRIB=$HOME/mcidas/bin/convert_grib_files.x
                               echo "debug1"
##------------
# Decide which forecast run to get and process

ctoday=$(  date  +%Y%m%d )
cyesterday=$(  date -d ' 1 day ago ' +%Y%m%d )

echo "ctoday=$ctoday"
echo "cyesterday=$cyesterday"

runDate=$ctoday

hh_now=$( date -u +%H )       # text string  between 00 and 23
if   [ $hh_now -lt 03 ] ; then
   HHrun='18'
   runDate=$cyesterday
elif [ $hh_now -lt 09 ] ; then
   HHrun='00'
elif [ $hh_now -lt 15 ] ; then
   HHrun='06'
elif [ $hh_now -lt 21 ] ; then
   HHrun='12'
else 
   HHrun='18'
fi
echo " Time is $(date) ; HHrun is $HHrun"    # Current date/time, model run time

##------------
#  Determine remote directory name and names of files to fetch
 
echo "runDate=$runDate"               # date of model run
remoteNcepDir=$ncepRootDir/gfs.$runDate     # remote server GFS data dir
echo " remoteNcepDir is $remoteNcepDir"

# file name samples: gfs.t12z.pgrb2f09.1p0deg     gfs.t12z.sfluxgrbf09.grib2

Fsuffix='1p0deg'
fname00="gfs.t${HHrun}z.pgrb2f00"
fname03="gfs.t${HHrun}z.pgrb2f03"
fname06="gfs.t${HHrun}z.pgrb2f06"
fname09="gfs.t${HHrun}z.pgrb2f09"
fname12="gfs.t${HHrun}z.pgrb2f12"
fname15="gfs.t${HHrun}z.pgrb2f15"
fname18="gfs.t${HHrun}z.pgrb2f18"


#-------------------------------------------------------------------
# Get and preprocess profile data

  cd $GRIB2_DIR_TEMP

##------------
#Pull model profiles to holding area

  echo " Begin get grib2 profiles hh=3 6 9 12 15 18 at $(date)"
  $HOME/mcidas/bin/sftptime -600 $user@$ncepDataServer << EOF     2>&1
    cd   $remoteNcepDir
   #get  $fname00.$Fsuffix    $fname00.$runDate.$Fsuffix
    get  $fname03.$Fsuffix    $fname03.$runDate.$Fsuffix
    get  $fname06.$Fsuffix    $fname06.$runDate.$Fsuffix
    get  $fname09.$Fsuffix    $fname09.$runDate.$Fsuffix
    get  $fname12.$Fsuffix    $fname12.$runDate.$Fsuffix
    get  $fname15.$Fsuffix    $fname15.$runDate.$Fsuffix
    get  $fname18.$Fsuffix    $fname18.$runDate.$Fsuffix
    bye
EOF
  if  [ $? -ne 0 ] ; then
     echo " $0: !!ERROR  $?: sftptime to ncep Failed or Timed Out !!"
     pwd ; ls -l
  fi

##------------
# Decode  each model profile, then move to work area
  echo " Begin decode profiles hh=3 6 9 12 15 18 at $(date)"

   cd   $GRIB2_DIR_TEMP  || (  echo "ERROR $0 no GRIB2_DIR_TEMP" && exit 1 )

   echo " Debug - pwd=`pwd`"
   echo " Debug - files available for decoding:  `ls`"

   for  fname in  $fname00 $fname03 $fname06 $fname09 $fname12 $fname15 $fname18
   do
       inname=$fname.$runDate.$Fsuffix
                   echo " Debug - now decode $inname " 
       outname=$fname.$runDate.dat
       infile=$GRIB2_DIR_TEMP/$inname
       tmpfile=$WORK_DIR_TEMP/$outname
       outfile=$WORK_DIR/$outname
       if [ -s $tmpfile ] || [ -s $outfile ] ; then 
          echo " Skip preprocessing $inname - already done "
       elif [ -s  $infile ] ; then
           echo "Begin preprocessing $inname $(date)"
           echo "$CONVERT_GRIB  $inname   $WORK_DIR_TEMP"
           time  $CONVERT_GRIB  $inname   $WORK_DIR_TEMP 
           rc=$?
           if [ $rc -eq 0 ]  &&  [ -s  $tmpfile ] ; then
              echo " Successfully preprocessed $inname $(date)"
              mv $tmpfile  $outfile
              mv $infile   $GRIB2_DIR/
           else
              echo " Failed preprocessing $inname - rc-$rc  $(date)"
              ls -l $tmpfile
           fi
       else  
            echo " Input file $inname  not found"
       fi
   done

#-------------------------------------------------------------------


#  Extra protection from disk fill up.
  DIRS="  $GRIB2_DIR  $GRIB2_DIR_TEMP  $WORK_DIR  $WORK_DIR_TEMP  "

 find $GRIB2_DIR       -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $GRIB2_DIR_TEMP  -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $WORK_DIR        -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
 find $WORK_DIR_TEMP   -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}

echo " End  $0 at $(date -u)"
echo ====================================================================
echo " End  $0 at $(date -u)"
echo ====================================================================



#  gfs.t06z.pgrb2.1p00.f009
#  gfs.t06z.pgrb2f09.1p0deg
