#!/bin/sh
#
#####################################################################
#
# Program Name: get_buoy.sh
#
# Purpose: Get buoy data for matchups vs goessst
#    -- Since the buoy data file is created by ncep at HH:50, get 
#   the previous hour's file if running earlier in the hour
#
# Usage: get_buoy.sh
#
# Change history:
#     ??????
#     09/03/04   M. Fan  (PSGS)
#                1) Add comment blocks
#                2) use set_app_env.sh 
#                -- modified from get_buoy_dist5.sh
#
#####################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#         daily log file
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done

# set remote server
#--------------------------
#remoteServer=gp9
remoteServer=10.144.3.42     # satepsdist5
remoteUser=oper
remoteRootDir=/data/ncep/input/nesdis/prod

# Create directory and filename for most recent buoy data file
#   Since the buoy data file is created by ncep at HH:50, get 
#   the previous hour's file if running earlier in the hour.
#   NCEP file: /com/nesdis/para/nesdis.YYYYMMDD/buoysst.ascii_HH
#-----------------------------------------------------------------------
cymd=$( date -u  -d'40 minutes ago'   +%Y%m%d )
yyyyddd=$( date -u  -d'40 minutes ago'   +%Y%j )
hour=$( date -u  -d'40 minutes ago'   +%H )
# --- remote directory
remoteDir=${remoteRootDir}/nesdis.${cymd}
# --- remote file name
remoteFile=${remoteDir}/buoysst.ascii_${hour}
# --- local file name
#LocalFile2=Buoysst.${hour}
LocalFile=buoysst.${hour}

echo  "=============================================================="
echo " Start $scriptname at $(date) "

echo "          cymd = $cymd "
echo "          hour = $hour "
echo "     remoteDir = $remoteDir "
echo "    remoteFile = $remoteFile "
echo "     LocalFile = $LocalFile "

# clean old file
#------------------
rm -f $LocalFile 
#rm -f $LocalFile2 

# go to mcidas data directory
#------------------------------
cd $MCDATDIR

# fetch the data
#------------------------------------------
#sftptime  $remoteUser@$remoteServer  << EOF   2>&1
#    ls -l $remoteFile
#    get  $remoteFile   $LocalFile
#EOF
scp  -p $remoteUser@$remoteServer:$remoteFile   $LocalFile
[ $? -eq 0 ]  &&  echo "Buoy data fetching successfuly"  || echo "Buoy data fetching failed"
[  -s  $LocalFile  ]  &&  cp  -p $LocalFile  $LocalFile.${yyyyddd}
find .  -type f -mmin +4320 | grep buoysst |xargs -i rm {}

echo "End $scriptname at `date -u`\n"

