#!/bin/ksh

#
### Get ncep gfs grib files from GP9
#   Files are used for generating L2P/netCDF formatted output for GOES-SST
#   This version gets  ** grib2 ** formatted ncep files

##---------------------------------------------------------------------
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs

LOGDIR=$HOME/mcidas/logs
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $0  -l logfile_name \n";;
           esac
done
##---------------------------------------------------------------------

# directory name sample :   /com/gfs/prod/gfs.20060322
# file name samples: gfs.t12z.pgrbf09  gfs.t00z.sfluxgrbf09

echo "===================================================="
echo " Execute $0 at $(date -u)"

user='oper'

ncepDataServer=10.144.3.42

ncepRootDir='/data/ncep/input/gfs/prod'


localDir=/data/$(whoami)/L2P/ncep
ctoday=$(  date  +%Y%m%d )
cyesterday=$(  date -d ' 1 day ago ' +%Y%m%d )

echo "ctoday=$ctoday"
echo "cyesterday=$cyesterday"

runDate=$ctoday

hh_now=$( date -u +%H ) 
if   [ $hh_now -lt 03 ] ; then
   HHrun='18'
   runDate=$cyesterday
elif [ $hh_now -lt 09 ] ; then
   HHrun='00'
elif [ $hh_now -lt 15 ] ; then
   HHrun='06'
elif [ $hh_now -lt 21 ] ; then
   HHrun='12'
else 
   HHrun='18'
fi
echo " Time is $(date) ; HHrun is $HHrun"

echo "runDate=$runDate"
ncepDir=$ncepRootDir/gfs.$runDate
echo " ncepDir is $ncepDir"

# file name samples: gfs.t12z.pgrb2f09.1p0deg     gfs.t12z.sfluxgrbf09.grib2




Fsuffix='1p0deg'
fname00="gfs.t${HHrun}z.pgrb2f00"
fname03="gfs.t${HHrun}z.pgrb2f03"
fname06="gfs.t${HHrun}z.pgrb2f06"
fname09="gfs.t${HHrun}z.pgrb2f09"
fname12="gfs.t${HHrun}z.pgrb2f12"
fname15="gfs.t${HHrun}z.pgrb2f15"
fname18="gfs.t${HHrun}z.pgrb2f18"

Ssuffix='grib2'
sname00="gfs.t${HHrun}z.sfluxgrbf00"
sname03="gfs.t${HHrun}z.sfluxgrbf03"
sname06="gfs.t${HHrun}z.sfluxgrbf06"
sname09="gfs.t${HHrun}z.sfluxgrbf09"
sname12="gfs.t${HHrun}z.sfluxgrbf12"
sname15="gfs.t${HHrun}z.sfluxgrbf15"
sname18="gfs.t${HHrun}z.sfluxgrbf18"

cd $localDir/tmp

echo " Begin get grib2 profiles hh=3 6 9 12 15 18 at $(date)"
$HOME/mcidas/bin/sftptime -600 $user@$ncepDataServer << EOF     2>&1
  cd   $ncepDir
 #get  $fname00.$Fsuffix    $fname00.$runDate.$Fsuffix
 #get  $fname03.$Fsuffix    $fname03.$runDate.$Fsuffix
  get  $fname06.$Fsuffix    $fname06.$runDate.$Fsuffix
  get  $fname09.$Fsuffix    $fname09.$runDate.$Fsuffix
  get  $fname12.$Fsuffix    $fname12.$runDate.$Fsuffix
  get  $fname15.$Fsuffix    $fname15.$runDate.$Fsuffix
  get  $fname18.$Fsuffix    $fname18.$runDate.$Fsuffix
  bye
EOF
if  [ $? -ne 0 ] ; then
   echo " $0: !!ERROR  $?: sftptime to ncep Failed or Timed Out !!"
   pwd ; ls -l
else
   pwd ; ls -l ;   mv gfs* ..
fi

echo " Begin get grib2 sflux  hh=   9 12 15 18   at $(date)"
$HOME/mcidas/bin/sftptime -600 $user@$ncepDataServer << EOF     2>&1
  cd   $ncepDir
  get  $sname09.$Ssuffix    $sname09.$runDate.$Ssuffix
  get  $sname12.$Ssuffix    $sname12.$runDate.$Ssuffix
  get  $sname15.$Ssuffix    $sname15.$runDate.$Ssuffix
  get  $sname18.$Ssuffix    $sname18.$runDate.$Ssuffix
  bye
EOF
if  [ $? -ne 0 ] ; then
   echo " $0: !!ERROR  $?: sftptime to ncep Failed or Timed Out !!"
   pwd ; ls -l
else
   pwd ; ls -l ;   mv gfs* ..
fi


#  Extra protection from disk fill up.
find . -mtime +2 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
find . -mtime +2 |grep "^gfs.t" |grep "z.sfluxgrbf" |xargs -i rm {}

echo " End  $0 at $(date -u)"
echo ====================================================================
