#! /bin/sh
#
#########################################################################################
#
# Program Name: sendL2P_2.0.sh
#
# Purpose: Send L2P to server
#
# Usage: $0 $1 $2
#        $1=server_option  (isOps/isTest/isBackup)  -- choose to send to operational,
#                          Test, or Backup server 
#        $2=l2p file name (e.g. 20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.nc)
#     Example:   sendL2P_goes.sh  isOps 20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.nc 
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in
#       set_server_Ops.sh, et_server_Test.sh, and set_server_Backup.sh
#
# Called by: L2P_proc.sh
#
# Scripts called: 
#         1. set_app_env.sh
#         2.set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#
# Change History:
#    01/11/07    sendL2P.sh -- send goes-sst L2P output files to Product Server
#    04/10/09  M. Fan  (PSGS)
#              1) Add comment blocks
#              2) Use set_app_env.sh
#              3) Use set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#              4) Use scp intead 0f sftp
#
##########################################################################################

# Sample Filename
# 20120626162200-OSPO-L2P_GHRSST-SSTskin-GOES15-South-v02.0-fv01.0.nc
#-------------------------------------------------------------------

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------

export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

# log file
#--------------
#datestring=`date -u +%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1

echo ""
echo "======================================="
echo " Execute $scriptname at $(date -u)"

## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname  <server_option> <L2P file name>"
    echo " e.g.     $scriptname  isTest  20120626162200-OSPO-L2P_GHRSST-SSTskin-GOES15-South-v02.0-fv01.0.nc"
    exit -1
fi

curdir=`pwd`


# server option
#----------------
server_option=$1

# L2P file
#--------------
l2pfile=$2
echo "l2pfile=$l2pfile"


# server info
#-------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup.sh

echo "remoteDir = $remoteDir"



# satType
#-------------------

satType='unknown'  ; remoteDir=/root/root/root

echo "goesL2pRemoteDir  = $goesL2pRemoteDir "
echo "mtsatL2pRemoteDir = $mtsatL2pRemoteDir "
echo "msgL2pRemoteDir   = $msgL2pRemoteDir "

echo "$l2pfile"       | grep  -i GOES   &&  satType='goes'   &&  remoteDir=$goesL2pRemoteDir 
echo "$l2pfile"       | grep  -i MTSAT  &&  satType='mtsat'  &&  remoteDir=$mtsatL2pRemoteDir
echo "$l2pfile"       | grep  -i MSG    &&  satType='msg'    &&  remoteDir=$msgL2pRemoteDir


if [ $satType = 'unknown' ]
then
    echo " Cannot figure out where $l2pfile should be sent"
    exit 1
fi

# products names : L2p
#---------------------

# -- L2P output directory
 cd $L2P_OUTDIR

# --  the file to send
     echo $l2pFile ; ls -l $l2pfile 

# -- md5
     [ ! -s    $l2pfile.md5  ]   &&    md5sum   $l2pfile  >  $l2pfile.md5

#  send to server
#-----------------
     rc=1
     for  file in  $l2pfile  $l2pfile.md5   
     do
         if [ -s $file ]
         then
              echo "$file"
              scp -p $file  $remoteUser@$remoteServer:$remoteDir
              rc=$?
              if [ $rc -eq 0 ]; then
                 cp -p $file  $L2P_SENTDIR/. 
              else
                 echo " Error $rc copying $file to $remoteServer"
              fi
         fi
     done

     if [ $rc -eq 0 ]; then
          echo "l2p send to server ($server_option) SUCCESS"
     else
          echo "l2p send to server ($server_option) FAIL"
     fi

 echo ".................."
 echo " End $scriptname at `date -u` "		# time stamp

 cd $curdir

