#!/bin/bash  

#
### Preprocess ncep gfs grib2 files for use by L2P
#

##---------------------------------------------------------------------
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs

LOGDIR=$HOME/mcidas/logs
while getopts l: optionName
do
            case $optionName in
            l)   inname="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$inname.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $0  -l logfile_name \n";;
           esac
done
##---------------------------------------------------------------------

# directory name sample :   /com/gfs/prod/gfs.20060322
# file name samples: gfs.t12z.pgrbf09  gfs.t00z.sfluxgrbf09

echo "===================================================="
echo " Execute $0 at $(date -u)"


# Executible program to preprocess gfs grib2 file
CONVERT_GRIB=$HOME/mcidas/bin/convert_grib_files.x

#input, temporary, output directories
GRIB2_DIR=/data/$(whoami)/L2P/ncep
TEMP_DIR=/data/$(whoami)/L2P/work/temp/
PROCESSED_DIR=/data/$(whoami)/L2P/work/

[ ! -d $GRIB2_DIR     ]  && echo " Missing directory GRIB2_DIR     = $GRIB2_DIR     " && exit 1
[ ! -d $TEMP_DIR      ]  && echo " Missing directory TEMP_DIR      = $TEMP_DIR      " && exit 1
[ ! -d $PROCESSED_DIR ]  && echo " Missing directory PROCESSED_DIR = $PROCESSED_DIR " && exit 1

ctoday=$(  date  +%Y%m%d )
cyesterday=$(  date -d ' 1 day ago ' +%Y%m%d )

echo "ctoday=$ctoday"
echo "cyesterday=$cyesterday"

runDate=$ctoday

hh_now=$( date -u +%H ) 
if   [ $hh_now -lt 04 ] ; then
   HHrun='18'
   runDate=$cyesterday
elif [ $hh_now -lt 10 ] ; then
   HHrun='00'
elif [ $hh_now -lt 16 ] ; then
   HHrun='06'
elif [ $hh_now -lt 22 ] ; then
   HHrun='12'
else 
   HHrun='18'
fi
echo " Time is $(date) ; HHrun is $HHrun"

echo "runDate=$runDate"

# file name samples: gfs.t12z.pgrb2f09.1p0deg     gfs.t12z.sfluxgrbf09.grib2


Fsuffix='1p0deg'
fname00="gfs.t${HHrun}z.pgrb2f00"
fname03="gfs.t${HHrun}z.pgrb2f03"
fname06="gfs.t${HHrun}z.pgrb2f06"
fname09="gfs.t${HHrun}z.pgrb2f09"
fname12="gfs.t${HHrun}z.pgrb2f12"
fname15="gfs.t${HHrun}z.pgrb2f15"
fname18="gfs.t${HHrun}z.pgrb2f18"

Ssuffix='grib2'
sname00="gfs.t${HHrun}z.sfluxgrbf00"
sname03="gfs.t${HHrun}z.sfluxgrbf03"
sname06="gfs.t${HHrun}z.sfluxgrbf06"
sname09="gfs.t${HHrun}z.sfluxgrbf09"
sname12="gfs.t${HHrun}z.sfluxgrbf12"
sname15="gfs.t${HHrun}z.sfluxgrbf15"
sname18="gfs.t${HHrun}z.sfluxgrbf18"

cd $localDir/tmp

date

  cd   $GRIB2_DIR

   for  fname in  $fname00 $fname03 $fname06 $fname09 $fname12 $fname15 $fname18
   do
       inname=$fname.$runDate.$Fsuffix
       outname=$fname.$runDate.dat

       infile=$GRIB2_DIR/$inname
       tmpfile=$TEMP_DIR/$outname
       outfile=$PROCESSED_DIR/$outname
                                                                          ls -l $infile
       if [ -s $outfile ] ; then 
          echo " Skip processing $inname - already done "
       elif [ -s  $infile ] ; then
           echo "Begin preprocessing $inname $(date)"
                                                                        file  $TEMP_DIR
           echo "$CONVERT_GRIB  $inname   $TEMP_DIR"
           time  $CONVERT_GRIB  $inname   $TEMP_DIR 
           rc=$?
           if [ $rc -eq 0 ]  &&  [ -s  $tmpfile ] ; then
              echo " Successfully preprocessed $inname $(date)"
              mv $tmpfile  $outfile
           else
              echo " Failed preprocessing $inname - rc-$rc  $(date)"
              ls -l $tmpfile
           fi
       else  
            echo " Input file $inname  not found"
       fi
   done

   for  sname in    $sname09  $sname12  $sname15  $sname18
   do
       inname=$sname.$runDate.$Ssuffix
       outname=$sname.$runDate.dat
       infile=$GRIB2_DIR/${inname}
       tmpfile=$TEMP_DIR/$outname
       outfile=$PROCESSED_DIR/$outname
       if [ -s $outfile ] ; then 
          echo " Skip processing $inname - already done "
       elif [ -s  $infile ] ; then
           echo "Preprocessing $inname begin $(date)"
           time  $CONVERT_GRIB  $inname   $TEMP_DIR
           rc=$?
           if [ $rc -eq 0 ] && [  -s  $tmpfile ] ; then
              echo " Successfully preprocessed $inname $(date)"
              mv $tmpfile  $outfile
           else
              echo " Failed preprocessing $inname - rc-$rc  $(date)"
              ls -l $tmpfile
           fi
       else  
            echo " Input file $inname  not found"
       fi
   done



#  Extra protection from disk fill up.

find $GRIB2_DIR     -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
find $TEMP_DIR      -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
find $PROCESSED_DIR -type f  -mmin +2160 |grep "^gfs.t" |grep "z.pgrb"      |xargs -i rm {}
find $GRIB2_DIR     -type f  -mmin +2160 |grep "^gfs.t" |grep "z.sfluxgrbf" |xargs -i rm {}
find $TEMP_DIR      -type f  -mmin +2160 |grep "^gfs.t" |grep "z.sfluxgrbf" |xargs -i rm {}
find $PROCESSED_DIR -type f  -mmin +2160 |grep "^gfs.t" |grep "z.sfluxgrbf" |xargs -i rm {}

echo " End  $0 at $(date -u)"
echo ====================================================================
