#!/bin/bash
#
# purpose: save MTSAT2R data 
#
# usage:   save.mtsat2R.sh yyyyddd hh
# Example: save.mtsat2R.sh 2009320 00
#
############################################################
# 
## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
export scriptname=$( basename $0 )

echo "`date -u` start $scriptname"       # time stamp


## Set time reference for data to be processed
#----------------------------------------------
# date=$(   date +%Y%j  -u -d"$age minutes ago" )
#hour=$(   date +%H    -u -d"$age minutes ago" )
date=$1
hour=$2


#               -----------------------------
#               MTSAT - FULL DISK
#               -----------------------------
#               Data comes at HH:30
#               Download (hh-1):30 data
#----------------------------------------------------------------

    min1=25
    min2=35

WHEN=" DAY=$date  TIME=$hour:$min1 $hour:$min2 "

echo "MTSAT image at $WHEN"


# Remove transition files
#---------------------------
imgdel.k LD/A.5990 5998


#  Copy the five band data  
#------------------------------------------------------------------
echo "  imgcopy.k   MTS/MTGLOB04I2      LD/A.5992  $WHEN   SIZE=SAME   "
        imgcopy.k   MTS/MTGLOB04I2      LD/A.5992  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I3      LD/A.5993  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I4      LD/A.5994  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB04I5      LD/A.5995  $WHEN   SIZE=SAME
        imgcopy.k   MTS/MTGLOB01V       LD/A.5990  $WHEN   SIZE=SAME

echo "Got MTSAT imagery  at `date -u`"
 

#  Average visible data to 4-km resolution  
#-----------------------------------------
        avgimi.k 5990 5991 4
#       imgdel.k LD/A.5990


## Combine the five band into one AREA-file: calling gimiglue 
#-----------------------------------------------------
name0=$AREADIR/AREA599
InList=`echo $name0"2" $name0"1" $name0"3" $name0"4" $name0"5"`

OutFile="${name0}8"

OutDSN=LD/A.5998

rm -f $OutFile

    gimiglue $OutFile  $InList
    rc1=$?

# delete garbage in and print error message
#---------------------------------------------
if [ $? -ne 0 ]
then
  echo "Error in gimiglue for $OutFile"
fi
imglist.k   LD/A.5990 5998

num_area=" 0 1 2 3 4 5 8 "
for f in $num_area
do
     scp -p $AREADIR/AREA599$f oper@10.144.3.43:/data/ftp/pub/goessst/mtsat2r/AREA599$f.$date.$hour
done


echo "`date -u` done copying data"
echo " End $scriptname at `date -u` "   # time stamp
echo " "
echo "================================================================="

