#! /bin/sh
#
#######################################################################################
#
# Program Name: send1b_mtsat.sh
#
# Purpose: Send hourly sst product to server
#
# Usage: send1b_mtsat.sh  <timeString> <server_option>
#        where timeString is date string, such as 2006_364_23
#              server_option is such as isOps, isTest, or isBackup   
#       Example: send1b_mtsat.sh  2009_098_18  isTest
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in 
#       set_server_Ops_daynite.sh, set_server_Test_daynite.sh, and set_server_Backup_daynite.sh
#   
# Called by: merge_mtsat.sh ...  
#
# Change History:
#    03/19/02   send1h.sh, send hourly SST files to Product Server
#    11/22/05   For Bayesian Files - compute name from proc hour
#    03/16/09  M.Fan  (PSGS)
#              1) Add comment blocks
#              2) Use set_app_env.sh
#              3) Use set_server_Ops_daynite.sh, or set_server_Test_daynite.sh, or set_server_Backup_daynite.sh
#              4) Use scp instead of sftp
#
#######################################################################################
#

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )
curDir=`pwd`


# log file
#-------------
#datestring=`date -u +%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo "`date -u` start $scriptname"              # time stamp


## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname  <timeString>  <server_option>"
    echo " where timeString is date string, such as 2006_364_23 "
    echo "       server_option is such as isOps, isTest, or isBackup"
    exit -1
fi


# time string and server option
#-------------------------------
timeString=$1
server_option=$2
echo "  $scriptname   epoch=$timeString   server_option=$server_option"


# remote server info
#---------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops_daynite.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test_daynite.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup_daynite.sh

remoteDir=$mtsatSST1hRemoteDir
echo "remoteDir = $remoteDir"
remoteDir2=$mtsatSSTdayNiteRemoteDir
echo "remoteDir2 = $remoteDir2"

# product
#--------------------
products=" sst1o_mtsat  sst1b_mtsat "


# Send to server
#----------------------
rc=1
for cprod in $products
do
    prodName=${cprod}_${timeString}
    prodFile=$SSTDIR/$prodName

    prodFile_day=${prodFile}'_day'
    gzip  $prodFile_day

    prodFile_nite=${prodFile}'_nite'
    gzip  $prodFile_nite


   ls -l $prodFile
   if [  -s $prodFile ]
   then
#      ftpsst  $prodName $remoteDir
       ftpdds.sh   $SSTDIR/$prodName  
       scp -p      $SSTDIR/$prodName  $remoteUser@$remoteServer:$remoteDir
       rc=$?
   else
      echo  "$scriptname: ERROR - SST file is not present, or is empty. - $prodName"
   fi

   ls -l $prodFile_day'.gz'
   if [  -s $prodFile_day'.gz' ]
   then
#      ftpsst  $prodName $remoteDir
       ftpdds.sh   $prodFile_day'.gz'   $remoteUser@$remoteServer:$remoteDir2 || echo "Error copying $prodFile_day'.gz'"
       scp -p      $prodFile_day'.gz'   $remoteUser@$remoteServer:$remoteDir2 || echo "Error copying $prodFile_day'.gz'"
       rc=$?
   else
      echo  "$scriptname: ERROR - SST file is not present, or is empty. - $prodName_day'.gz'"
   fi

   ls -l $prodFile_nite'.gz'
   if [  -s $prodFile_nite'.gz' ]
   then
#      ftpsst  $prodName $remoteDir
       ftpdds.sh   $prodFile_nite'.gz'   $remoteUser@$remoteServer:$remoteDir2 || echo "Error copying $prodFile_nite'.gz'"
       scp -p      $prodFile_nite'.gz'   $remoteUser@$remoteServer:$remoteDir2 || echo "Error copying $prodFile_nite'.gz'"
       rc=$?
   else
      echo  "$scriptname: ERROR - SST file is not present, or is empty. - $prodName_day'.gz'"
   fi

if [ $rc -eq 0 ]
then
       echo "1-hourly send to server ($server_option) SUCCESS"
else
       echo "1-hourly send to server ($server_option) FAIL"
fi

done

 echo "End $scriptname  $* at $(date)"
 echo "================================="
exit 0
