#! /bin/sh
#
#######################################################################################
#
# Program Name: send3b_goes.sh
#
# Purpose: Send 3-hourly sst products to server (including coast watch)
#
# Usage: send3b_goes.sh  <timeString>   <server_option>
#        where timeString is date string, such as 2006_364_18
#              server_option is such as isOps, isTest, or isBackup
#       Example:  send3b_goes.sh  2009_098_18   isTest
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in 
#       set_server_Ops.sh, et_server_Test.sh, and set_server_Backup.sh
#
# Called by: merge_goes.sh
#
# Change History:
#    03/19/02   send1h.sh, send hourly SST files to Product Server
#    11/22/05    For Bayesian Files - compute name from proc hour
#    03/16/09  M. Fan  (PSGS)
#              1) Add comment blocks
#              2) Use set_app_env.sh
#              3) Use set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#              4) Use scp instead of sftp
#
#######################################################################################
#

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )
curDir=`pwd`

# log file
#-------------
#datestring=`date -u +%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo "`date -u` start $scriptname"              # time stamp


## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname  <timeString>  <server_option>"
    echo " where timeString is date string, such as 2006_364_23 "
    echo "       server_option is such as isOps, isTest, or isBackup"
    exit -1
fi


# time string and server option
#-------------------------------
timeString=$1
server_option=$2
echo "  $scriptname   epoch=$timeString   server_option=$server_option"


# remote server info
#---------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup.sh

remoteDir=$goesSST3hRemoteDir
echo "remoteDir = $remoteDir"

# product
#--------------------
#products=' sst3b  sst3o  sst3bE  sst3oE  sst3bW  sst3oW '
products=' sst3b_goes  sst3o_goes  sst3b_goesE  sst3o_goesE  sst3b_goesW  sst3o_goesW '

filenames_cw=$( ls $SSTDIR |grep sst3 |grep $timeString  |grep "[A-Y]$" )


# Send to server
#----------------------
for cprod in $products
do
    prodName=${cprod}_${timeString}

   ls -l $SSTDIR/$prodName

   if [  -s $SSTDIR/$prodName ]
   then
#      ftpsst  $prodName $remoteDir
       ftpdds.sh  $SSTDIR/$prodName  
       scp $SSTDIR/$prodName  $remoteUser@$remoteServer:$remoteDir
   else
      echo  "$scriptname: ERROR - SST file is not present, or is empty. - $prodName"
   fi
done

# Send to server -- for coast watch
#----------------------------------
rc=1
remoteDir=$goesSST3h_cwRemoteDir
echo "remoteDir = $remoteDir"

for cprod in $filenames_cw
do
    prodName=${cprod}

   ls -l $SSTDIR/$prodName

   if [  -s $SSTDIR/$prodName ]
   then
#     ftpsst  $prodName $remoteDir
      ftpdds.sh  $SSTDIR/$prodName 
      scp $SSTDIR/$prodName  $remoteUser@$remoteServer:$remoteDir
       rc=$?
   else
      echo  "$scriptname: ERROR - SST file is not present, or is empty. - $prodName"
   fi
done


if [ $rc -eq 0 ]
then
     echo "3-hourly send to server ($server_option) SUCCESS"
else
     echo "3-hourly send to server ($server_option) FAIL"
fi


 echo "End $scriptname  $* at $(date)"
 echo "================================="
exit 0
