#! /bin/sh
#
#########################################################################################
#
# Program Name: sendBuoyMatch_msg.sh
#
# Purpose: Send buoy matchup to server
#
# Usage: $0 $1 $2 
#        $1=ccyy_ddd_hh
#        $2=server_option  (isOps/isTest/isBackup)
#     Example:   sendBuoyMatch_msg.sh  2009_045_09  isOps
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in 
#       set_server_Ops.sh, et_server_Test.sh, and set_server_Backup.sh
#
# Called by:  buoyMatch_msg.sh
#
# Scripts called: 
#         1. set_app_env.sh
#         2. set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#
# Description: 
#         1. send the compressed buoy matchup to server
#         2. if sending is successful, the buoy match at "old" directory will be compressed,
#            otherwise is uncompressed.
#
# Change History:
#   03/17/02 -- sendBuoyMatch. derived from old fredmatch script
#   03/16/09  M. Fan  (PSGS)
#             1) Add comment blocks
#             2) Use set_app_env.sh
#             3) Use set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#             4) Use scp instead of sftp
#             -- Modified from sendBuoyMatch_msg.dist1.sh 
#
##########################################################################################
#

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

# log file
#--------------
#datestring=`date -u +%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo "`date -u` start $scriptname"              # time stamp


## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname <ccyy_ddd_hh>  <server_option>"
    exit -1
fi


## Get time reference from arguments
#------------------------------------
ccyy_ddd_hh=$1
year=` echo  ${ccyy_ddd_hh} |cut -c1-4 `
day=`  echo  ${ccyy_ddd_hh} |cut -c6-8 `
hour=` echo  ${ccyy_ddd_hh} |cut -c10-11 `
datestring="${year}_${day}.${hour}"


# server option
#----------------
server_option=$2


# match string
#----------------
match_string=match_msg_


# server info
#-------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup.sh

remoteDir=$msgBuoyRemoteDir
echo "remoteDir = $remoteDir"


## File names: buoy match results
#--------------------------------
nameB=${match_string}${datestring}'B'
nameS=${match_string}${datestring}'S'

## copy, compress and send: $nameB
#---------------------------------
echo "input name is ${nameB}"
ls -l  $BUOYDIR/$nameB

if [  -s $BUOYDIR/$nameB ]
then
      chmod 644 ${BUOYDIR}/${nameB}
      cp ${BUOYDIR}/${nameB}  ${oldBUOYDIR}/${nameB}
      gzip   ${BUOYDIR}/${nameB}
      [  -s $BUOYDIR/${nameB}.gz ]  && ftpdds.sh  $BUOYDIR/${nameB}.gz  
      [  -s $BUOYDIR/${nameB}.gz ]  && scp  -p $BUOYDIR/${nameB}.gz  $remoteUser@$remoteServer:$remoteDir
      rc1=$?
      if [ $rc1 -eq 0 ]; then
         echo "Return value of scp: $rc1"
         gzip   ${oldBUOYDIR}/${nameB}
         echo "${nameB}.gz was sent to server ($server_option)"
      fi
elif [  -s $BUOYDIR/${nameB}.gz ]
then
      ftpdds.sh   $BUOYDIR/${nameB}.gz  $remoteUser@$remoteServer:$remoteDir
      scp -p $BUOYDIR/${nameB}.gz  $remoteUser@$remoteServer:$remoteDir
      rc1=$?
      if [ $rc1 -eq 0 ]; then
          echo "${nameB}.gz was sent to server ($server_option)"
      fi
else
   echo Buoy matchup file is not present, or is zero size.
fi

## copy, compress and send: $nameS 
#---------------------------------
echo "input name is ${nameS}"
ls -l  $BUOYDIR/$nameS

if [  -s $BUOYDIR/$nameS ]
then
      chmod 644 ${BUOYDIR}/${nameS}
      cp ${BUOYDIR}/${nameS}  ${oldBUOYDIR}/${nameS}
      gzip   ${BUOYDIR}/${nameS}
      [  -s $BUOYDIR/${nameS}.gz ]  && ftpdds.sh  $BUOYDIR/${nameS}.gz  
      [  -s $BUOYDIR/${nameS}.gz ]  && scp  -p $BUOYDIR/${nameS}.gz  $remoteUser@$remoteServer:$remoteDir
      rc2=$?
      if [ $rc2 -eq 0 ]; then
         echo "buoy matchup send to server ($server_option) SUCCESS"
         gzip   ${oldBUOYDIR}/${nameS} 
         echo "${nameS}.gz was sent to server"
      else
         echo "buoy matchup send to server ($server_option) FAIL"
      fi
elif [  -s $BUOYDIR/${nameS}.gz ]
then
      ftpdds.sh    $BUOYDIR/${nameS}.gz 
      scp -p $BUOYDIR/${nameS}.gz  $remoteUser@$remoteServer:$remoteDir
      rc2=$?
      if [ $rc2 -eq 0 ]; then
         echo "buoy matchup send to server ($server_option) SUCCESS"
         echo "${nameS}.gz was sent to server"
      else
         echo "buoy matchup send to server ($server_option) FAIL"
      fi
else
   echo "Buoy matchup file ${BUOYDIR}/${nameS} is not present, or is zero size."
fi

 echo "End $scriptname  $* at $(date)"
 echo "=============================="

exit 0



