#! /bin/sh
#
#########################################################################################
#
# Program Name: sendFront_goes.sh
#
# Purpose: Send GOES front SST to server
#
# Usage: $0 $1 $2
#        $1=front  SST file name, such as gsst_2009_265_frt.gz
#        $2=server_option  (isOps/isTest/isBackup)  -- choose to send to operational,
#                          Test, or Backup server 
#     Example:   sendFront_goes.sh  gsst_2009_265_frt.gz  isOps 
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in
#       set_server_Ops.sh, et_server_Test.sh, and set_server_Backup.sh
#
# Called by: run_front.sh
#
# Scripts called: 
#         1. set_app_env.sh
#         2.set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#
# Change History:
#    10/01/09   M. Fan (PSGS) 
#
##########################################################################################

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------

export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

echo ""
echo "======================================="
echo " Execute $scriptname at $(date -u)"

## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname  <Front_SST file name>  <server_option>"
    echo " e.g.     $scriptname  gsst_2009_265_frt.gz  isTest"
    exit -1
fi

curdir=`pwd`


# from argument 
#----------------
frtfile=$1
server_option=$2

# server info
#-------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup.sh

remoteDir=$goesFrontRemoteDir
echo "remoteDir = $remoteDir"

# -- goto front_SST output directory
 cd $FRONTDIR/daily_fronts


#  send to server
#-----------------
 scp -p $frtfile  $remoteUser@$remoteServer:$remoteDir/.
 rc=$?
if [ $rc -eq 0 ]; then
       echo "front_sst send to server ($server_option) SUCCESS"
 else
       echo "front_sst send to server ($server_option) FAIL"
 fi

 echo ".................."
 echo " End $scriptname at `date -u` "		# time stamp

 cd $curdir

