#! /bin/sh
#
#########################################################################################
#
# Program Name: sendL2P_msg.sh
#
# Purpose: Send L2P to server
#
# Usage: $0 $1 $2
#        $1=server_option  (isOps/isTest/isBackup)  -- choose to send to operational,
#                          Test, or Backup server 
#        $2=l2p file name (e.g. 20061219-MSG02-OSDPD-L2P-MSG02_1600Z-v01.nc)
#     Example:   sendL2P_msg.sh  isOps 20061219-MSG02-OSDPD-L2P-MSG02_1600Z-v01.nc 
#
# NOTE: If server related info, such the IP changed, make the corresponding changes in
#       set_server_Ops.sh, et_server_Test.sh, and set_server_Backup.sh
#
# Called by: L2P_proc.sh
#
# Scripts called: 
#         1. set_app_env.sh
#         2.set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#
# Change History:
#    01/11/07    sendL2P.sh -- send goes-sst L2P output files to Product Server
#    04/10/09  M. Fan  (PSGS)
#              1) Add comment blocks
#              2) Use set_app_env.sh
#              3) Use set_server_Ops.sh, or set_server_Test.sh, or set_server_Backup.sh
#              4) Use scp intead 0f sftp
#
##########################################################################################

# Sample Filenames
#               20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.nc.gz
#            FR-20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.xml
#-------------------------------------------------------------------

## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------

export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

# log file
#--------------
#datestring=`date -u +%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1


echo ""
echo "===================================================="
echo " Execute $scriptname at $(date -u)"

## Usage prompt
#----------------------------
if [ $# -ne 2 ]
then
    echo "USAGE:    $scriptname  <server_option> <L2P file name>"
    echo " e.g.     $scriptname  isTest 20061219-MSG02-OSDPD-L2P-MSG02_1600Z-v01.nc"
    exit -1
fi

curdir=`pwd`


# server option
#----------------
server_option=$1

# L2P file
#--------------
l2pfile=$2.gz


# server info
#-------------------
echo "$server_option" | grep isOps     &&  . $SCRIPTDIR/set_server_Ops.sh
echo "$server_option" | grep isTest    &&  . $SCRIPTDIR/set_server_Test.sh
echo "$server_option" | grep isBackup  &&  . $SCRIPTDIR/set_server_Backup.sh

remoteDir=$msgL2pRemoteDir
echo "remoteDir = $remoteDir"


# products names : L2p
#---------------------

# -- L2P output directory
 cd $L2P_OUTDIR

         ####  FR-20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.xml
         ####     20061219-GOES11-OSDPD-L2P-GOES11_North_1600Z-v01.nc.gz

# -- xml format
     xmlfile=$(echo  $l2pfile |sed  's/^2*/FR-2/' | sed 's/.gz$//'|sed 's/.nc$/.xml/')
     echo $l2pFile ; ls -l $l2pfile 
     echo $xmlFile ; ls -l $xmlfile 
# -- md5
     [ ! -s    $l2pfile.md5  ]   &&    md5sum   $l2pfile  >  $l2pfile.md5
     [ ! -s    $xmlfile.md5  ]   &&    md5sum   $xmlfile  >  $xmlfile.md5

#  send to server
#-----------------
     rcsum=0
     for  file in  $l2pfile  $l2pfile.md5  $xmlfile  $xmlfile.md5 
     do
         rc=100
         if [ -s $file ]
         then
              echo "$file"
              scp -p $file  $remoteUser@$remoteServer:$remoteDir
              rc=$?
              if [ $rc -eq 0 ]; then
                 cp -p $file  $L2P_SENTDIR/. 
              else
                 echo  "$0: Error $rc  sending $file  to server"
              fi
         fi
         let rcsum=$rcsum+$rc
     done

     if [ $rcsum -eq 0 ]; then
          echo "l2p send to server ($server_option) SUCCESS"
     else
          echo "l2p send to server ($server_option) FAIL"
     fi
 
 echo " End $scriptname at `date -u` "		# time stamp

 cd $curdir

