#! /bin/sh
#
#######################################################################################
#
# Program Name: send_dds_gzip.sh
#
# Purpose: Send geosst products to dds, gzipped
#
# Usage: send_ddz_gzip.sh    Filepath/Filename
#       Note that if file not compressed,  this will create temporary compressed version
#       Example:  send_dds_gzip.sh  sst1b_2009_365_13A
#
# Logic:
#    Need local file directory, local file name, holding directory, remote info
#    Verify directories, file exist
#    Link or create zipped file in holding directory
#    copy file to dds
#       copy as <file>.xfer
#       rename to <file>
#       delete from holding directory
#       log successful transfer
#    If fail at any point, log error in transfer
#
# Called by: merge_*, buoyMatch*
#
#    12/05/14  B Potash    Initial version
#              1) 
#
#######################################################################################
#


## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
 export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh

 export scriptname=$( basename $0 )
 export curDir=`pwd`
 export  ERR="!! $scriptname ERROR:"

# log file for sending
#---------------------------------------------------------------------
 export  datestring=`date -u +%Y%j`
 export  logname=sendlog.$(whoami).$(hostname -s).$datestring
 export  SENDLOG=$LOGDIR/$logname
 export  TEMPLOG=$LOGDIR/sendlogTemp.$$
                                            echo " DEBUG 0 TEMPLOG=$TEMPLOG"
#export  XFERDIR=/data/$(whoami)/xferData      # done in set_app_env
#exec >> $SENDLOG   2>&1

## message
 echo " "
 echo "================================================================"
 echo "`date -u` start $scriptname"              # time stamp


## Usage prompt
#----------------------------
 if [ $# -lt 1 ]
 then
    echo "USAGE:    $scriptname  FileToSend"
    exit -1
 fi

 FileToSend=$1

# Define and verify files and directories
#-------------------------------------------------
                                                 echo DEBUG-1 FileToSend=$FileToSend

 remoteServer=10.144.3.7       # DDS
 remoteUser="F0243"            # geo_sst account on DDS
 remoteDir=push

 localDir=$(  dirname  $FileToSend)
 localName=$( basename $FileToSend)

                                                 echo DEBUG-1a
 [ !  -f  $localDir/$localName ] &&  echo "$ERR - File $FileToSend Not Found" && exit 1
                                                 echo DEBUG-1b
 [ !  -d $XFERDIR ]              &&  mkdir  $XFERDIR
                                                 echo DEBUG-1c
 [ !  -d $XFERDIR ]              &&  echo "$ERR - xferdir $XFERDIR Not Found" && exit 1
                                                 echo DEBUG-1d
                                                 echo DEBUG-2

#Assume file is zipped, if that's what is desired
#-------------------------------------------------
 remoteName=$localName
 [    -h  $XFERDIR/$remoteName ]  ||  ln -s $localDir/$localName $XFERDIR/$remoteName
 [ !  -h  $XFERDIR/$remoteName ]  &&  echo "$ERR putting $remoteName in $XFERDIR"  &&  exit 1

                                                 echo DEBUG-3

# Put file on remote server
#    first as <name>.xfer, then rename to strip .xfer
#-------------------------------------------------
                                                 echo  "DEBUG-directory listing for file to transfer-start"
                                                 ls -l $XFERDIR/${remoteName}   
                                                 echo  "DEBUG-directory listing for file to transfer-end"

 touch $TEMPLOG
 #ftptime  -200  $remoteServer  <<EOF    >  $TEMPLOG  2>&1
                                                 echo "DEBUG- begin ftp --------------------------------"
 ftptime            $remoteServer  <<EOF    
    cd  $remoteDir
    put $XFERDIR/${remoteName}   ${remoteName}.xfer
    rename ${remoteName}.xfer  ${remoteName}
    dir ${remoteName}
EOF
 rc1=$?
                                                 echo "DEBUG- end ftp ----------------------------------"
                                                 echo DEBUG-4  rc1=$rc1
                                                 echo "DEBUG -------------- cat TEMPLOG=$TEMPLOG "
						 cat $TEMPLOG
                                                 echo DEBUG --------------- end cat TEMPLOG
 grep 'Transfer complete'  $TEMPLOG  >/dev/null  2>&1   ;  rc2=$?
 grep 'Rename successful'  $TEMPLOG  >/dev/null  2>&1   ;  rc3=$?
 if [ $rc1 -ne 0 ] 
 then
     echo " $ERR sending $localName - ftptime timed out "
 elif [ $rc2 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect SUCCESS message "
 elif [ $rc3 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect rename .xfer message "
 else
    echo Success  $localName sent to DDS at $(date)  |tee   $TEMPLOG
    rm $XFERDIR/$remoteName
 fi
                                                 echo DEBUG-5

 let rcsum=$rc1+$rc2+$rc3

 if [ $rcsum  -eq  0 ]
 then
    echo Success  $localName sent to DDS at $(date)  |tee   $TEMPLOG
 else
    echo Failure  $localName  not sent to DDS at $(date)  |tee   $TEMPLOG
 fi


 echo "End $scriptname  $* at $(date)"
 echo "================================="
 exit    $rcsum





#226 Transfer complete.
#26 bytes sent in 3.7e-05 seconds (6.9e+02 Kbytes/s)
#ftp> rename testfile.xfer testfile
#350 Ready for RNTO.
#250 Rename successful.

