#!/bin/bash
#
# Program Name: set_app_env.sh
#
# Purpose : Set up directory paths for SST processing
#
# Usage: set_app_env.sh 
#
# Scripts Run:  none
#
# Called by :  almost all scripts
#
# Description : Set up directory paths for SST processing
#
# Change History:
#      Feb. 2009 --  M. Fan (PSGS) 
#
################################################################################

# set path
#----------
export PATH=$HOME/mcidas/bin:$HOME/mcidas/scripts:/home/mcidas/bin:/bin:/usr/local/bin:/usr/bin:/etc:/usr/sbin:.
export MCPATH=$HOME/mcidas/data:/data/$(whoami)/AreaFiles:/home/mcidas/data

# set system directories
#------------------------
export LOGDIR=$HOME/mcidas/logs
# export LOGDIR=/home/sstgeo/mcidas/logs
#export SCRIPTDIR=$HOME/mcidas/ksh
export SCRIPTDIR=$( dirname $0 )
export BINDIR=$HOME/mcidas/bin
export MCDATDIR=$HOME/mcidas/data

# set in/output directories
#--------------------------
export SSTDIR=/data/$(whoami)/sstArchive
export AREADIR=/data/$(whoami)/AreaFiles
export MODELDIR=/data/$(whoami)/gridFiles   
export BUOYDIR=/data/$(whoami)/buoyMatch
export L2P_DIR=/data/$(whoami)/L2P
export L2P_DATA=/data/$(whoami)/L2P
export L2P_OUTDIR=${L2P_DATA}/netcdf_output
export L2P_INDIR=${L2P_DATA}/netcdf_input
export FRONTDIR=/data/$(whoami)/front_sst
export XFERDIR=/data/$(whoami)/xferDir

# modified since there is no enough disk space on /data but on /data1
# So the old/archive data are put under /data1
#-----------
#export MOD_ARCHIVE_DIR=/data/$(whoami)/modelArchive
#export oldBUOYDIR=/data/$(whoami)/buoyMatch/old
#export L2P_SENTDIR=${L2P_DATA}/netcdf_sent
#export L2P_OLDIN=${L2P_INDIR}/old

#export oldSSTDIR=/data/$(whoami)/sstArchive/old
#export oldArea=/data/$(whoami)/archiveAreaFiles

#isData1=$( ls /data1 2>/dev/null )
#if [[ $isData1 == "" ]]; then
#3   arch_dir="data"
#else
#   arch_dir="data1"
#fi

if   [ -d  "/data1" ]     # if /data1 exists as a directory
then
   arch_dir="data1"
else
   arch_dir="/data"
fi
    

export MOD_ARCHIVE_DIR=/${arch_dir}/$(whoami)/modelArchive
export oldBUOYDIR=/${arch_dir}/$(whoami)/buoyMatch/old
export L2P_SENTDIR=/${arch_dir}/$(whoami)/L2P/netcdf_sent
export L2P_OLDIN=/${arch_dir}/$(whoami)/L2P/netcdf_input/old
export oldSSTDIR=/${arch_dir}/$(whoami)/sstArchive/old
export oldArea=/${arch_dir}/$(whoami)/archiveAreaFiles




